==> otu-5000-17.04.tar: acterna/release/smartotu/app/serviceshelper/maintenance/SMTLicenseList.php <==
<?php
// *********************************************************
// NOTICE: All rights reserved. This material contains the
// trade secrets and confidential information of JDSU
// which embody substantial creative effort,
// ideas and expressions. No part of this material may be
// reproduced or transmitted in any form or by any means,
// electronic, mechanical, optical or otherwise, including
// photocopying and recording or in connection with any
// information storage or retrieval system, without
// specific written permission from JDSU
// Copyright JDSU 2013. All rights reserved.
// *********************************************************
namespace app\serviceshelper\maintenance;

/**
 * Isu licenses.
 * 
 * @author Sylvain Desplat
 */
final class SMTLicenseList
{
	
	const SSH_KEY_ACCESS= "SSH_KEY_ACCESS";
	const ENHANCEDSECURITY = "ENHANCEDSECURITY";
	const PEAK_MON= "PEAK_MON";
	const DUAL_OS= "DUAL_OS";
	const EXT_TEMP_RANGE= "EXT_TEMP_RANGE";
	const PON_TEST= "OTU_PON";
	const SAA= "SMART_ACCESS_ANYWHERE";
	
	const OTU_OPTION_HIGH_SEC = "HIGHSEC";
	const OTU_OPTION_SSH_KEY_ACCESS = "ACCESS";
	const OTU_OPTION_PEAK_MONITORING = "PEAK";
	const OTU_OPTION_DUAL_OS_MONITORING = "DUAL_OS";
	const OTU_OPTION_EXT_TEMP_RANGE_MONITORING = "EXT_TEMP_RANGE";
	const OTU_OPTION_TEST_PON_MONITORING = "TEST_PON";
	const OTU_OPTION_SAA_L2_MONITORING = "SAA_L2";	

	const ISU_OPTION_SAA_L2_MONITORING = "SMART_ACCESS_L2";
	
// NOT VALID IN PHP 5.4 (OTU8Kv2)	
// 	const OTU_OPTIONS = array(self::OTU_OPTION_HIGH_SEC=>self::SSH_KEY_ACCESS,
// 							  self::OTU_OPTION_SSH_KEY_ACCESS=>self::ENHANCEDSECURITY,
// 			                  self::OTU_OPTION_PEAK_MONITORING=>self::PEAK_MON,
// 							  self::OTU_OPTION_DUAL_OS_MONITORING=>self::DUAL_OS,
// 							  self::OTU_OPTION_EXT_TEMP_RANGE_MONITORING=>self::EXT_TEMP_RANGE,
// 							  self::OTU_OPTION_TEST_PON_MONITORING=>self::PON_TEST,
// 							  self::OTU_OPTION_SAA_L2_MONITORING=>self::SAA);

	private static $OTU_OPTIONS = array(self::OTU_OPTION_HIGH_SEC=>self::SSH_KEY_ACCESS,
										self::OTU_OPTION_SSH_KEY_ACCESS=>self::ENHANCEDSECURITY,
										self::OTU_OPTION_PEAK_MONITORING=>self::PEAK_MON,
										self::OTU_OPTION_DUAL_OS_MONITORING=>self::DUAL_OS,
										self::OTU_OPTION_EXT_TEMP_RANGE_MONITORING=>self::EXT_TEMP_RANGE,
										self::OTU_OPTION_TEST_PON_MONITORING=>self::PON_TEST,
										self::OTU_OPTION_SAA_L2_MONITORING=>self::SAA);
	
	static function getLicenseName( $scpiKey )
	{
// 		$licenseName ="";
// 		switch($scpiKey)
// 		{
// 			case self::OTU_OPTION_HIGH_SEC:
// 				$licenseName = self::ENHANCEDSECURITY;
// 				break;
// 			case self::OTU_OPTION_SSH_KEY_ACCESS:
// 				$licenseName = self::SSH_KEY_ACCESS;
// 				break;
// 			case self::OTU_OPTION_PEAK_MONITORING:
// 				$licenseName = self::PEAK_MON;
// 				break;
// 			case self::OTU_OPTION_DUAL_OS_MONITORING:
// 				$licenseName = self::DUAL_OS;
// 				break;
// 			case self::OTU_OPTION_EXT_TEMP_RANGE_MONITORING:
// 				$licenseName = self::EXT_TEMP_RANGE;
// 				break;
// 			case self::OTU_OPTION_TEST_PON_MONITORING:
// 				$licenseName = self::PON_TEST;
// 				break;
// 			case self::OTU_OPTION_SAA_L2_MONITORING:
// 				$licenseName = self::SAA;
// 				break;
// 		}
		return self::$OTU_OPTIONS[$scpiKey];
	}
	
	static function getOtuOptionList()
	{
		return self::$OTU_OPTIONS;
	}
}
?>

==> otu-5000-17.16.tar: acterna/release/smartotu/app/serviceshelper/maintenance/SMTLicenseList.php <==
<?php
// *********************************************************
// NOTICE: All rights reserved. This material contains the
// trade secrets and confidential information of JDSU
// which embody substantial creative effort,
// ideas and expressions. No part of this material may be
// reproduced or transmitted in any form or by any means,
// electronic, mechanical, optical or otherwise, including
// photocopying and recording or in connection with any
// information storage or retrieval system, without
// specific written permission from JDSU
// Copyright JDSU 2013. All rights reserved.
// *********************************************************
namespace app\serviceshelper\maintenance;

/**
 * Isu licenses.
 * 
 * @author Sylvain Desplat
 */
final class SMTLicenseList
{
	
	const SSH_KEY_ACCESS= "SSH_KEY_ACCESS";
	const ENHANCEDSECURITY = "ENHANCEDSECURITY";
	const PEAK_MON= "PEAK_MON";
	const DUAL_OS= "DUAL_OS";
	const EXT_TEMP_RANGE= "EXT_TEMP_RANGE";
	const PON_TEST= "OTU_PON";
	const SAA= "SMART_ACCESS_ANYWHERE";
	
	const OTU_OPTION_HIGH_SEC = "HIGHSEC";
	const OTU_OPTION_SSH_KEY_ACCESS = "ACCESS";
	const OTU_OPTION_PEAK_MONITORING = "PEAK";
	const OTU_OPTION_DUAL_OS_MONITORING = "DUAL_OS";
	const OTU_OPTION_EXT_TEMP_RANGE_MONITORING = "EXT_TEMP_RANGE";
	const OTU_OPTION_TEST_PON_MONITORING = "TEST_PON";
	const OTU_OPTION_SAA_L2_MONITORING = "SAA_L2";	

	const ISU_OPTION_SAA_L2_MONITORING = "SMART_ACCESS_L2";
	
// NOT VALID IN PHP 5.4 (OTU8Kv2)	
// 	const OTU_OPTIONS = array(self::OTU_OPTION_HIGH_SEC=>self::SSH_KEY_ACCESS,
// 							  self::OTU_OPTION_SSH_KEY_ACCESS=>self::ENHANCEDSECURITY,
// 			                  self::OTU_OPTION_PEAK_MONITORING=>self::PEAK_MON,
// 							  self::OTU_OPTION_DUAL_OS_MONITORING=>self::DUAL_OS,
// 							  self::OTU_OPTION_EXT_TEMP_RANGE_MONITORING=>self::EXT_TEMP_RANGE,
// 							  self::OTU_OPTION_TEST_PON_MONITORING=>self::PON_TEST,
// 							  self::OTU_OPTION_SAA_L2_MONITORING=>self::SAA);

	private static $OTU_OPTIONS = array(self::OTU_OPTION_HIGH_SEC=>self::ENHANCEDSECURITY,
										self::OTU_OPTION_SSH_KEY_ACCESS=>self::SSH_KEY_ACCESS,
										self::OTU_OPTION_PEAK_MONITORING=>self::PEAK_MON,
										self::OTU_OPTION_DUAL_OS_MONITORING=>self::DUAL_OS,
										self::OTU_OPTION_EXT_TEMP_RANGE_MONITORING=>self::EXT_TEMP_RANGE,
										self::OTU_OPTION_TEST_PON_MONITORING=>self::PON_TEST,
										self::OTU_OPTION_SAA_L2_MONITORING=>self::SAA);
	
	static function getLicenseName( $scpiKey )
	{
// 		$licenseName ="";
// 		switch($scpiKey)
// 		{
// 			case self::OTU_OPTION_HIGH_SEC:
// 				$licenseName = self::ENHANCEDSECURITY;
// 				break;
// 			case self::OTU_OPTION_SSH_KEY_ACCESS:
// 				$licenseName = self::SSH_KEY_ACCESS;
// 				break;
// 			case self::OTU_OPTION_PEAK_MONITORING:
// 				$licenseName = self::PEAK_MON;
// 				break;
// 			case self::OTU_OPTION_DUAL_OS_MONITORING:
// 				$licenseName = self::DUAL_OS;
// 				break;
// 			case self::OTU_OPTION_EXT_TEMP_RANGE_MONITORING:
// 				$licenseName = self::EXT_TEMP_RANGE;
// 				break;
// 			case self::OTU_OPTION_TEST_PON_MONITORING:
// 				$licenseName = self::PON_TEST;
// 				break;
// 			case self::OTU_OPTION_SAA_L2_MONITORING:
// 				$licenseName = self::SAA;
// 				break;
// 		}
		return self::$OTU_OPTIONS[$scpiKey];
	}
	
	static function getOtuOptionList()
	{
		return self::$OTU_OPTIONS;
	}
}
?>
